@@ -7,3 +7,12 @@ from .movement_matrix import movement_matrix
 from .movement_circles import movement_circles
 from .utilities import images_to_gif
 from .motiontransparency import motiontransparency_parameters, motiontransparency_images
+
+
+__all__ = [
+    "movement_matrix",
+    "movement_circles",
+    "images_to_gif",
+    "motiontransparency_parameters",
+    "motiontransparency_images",
+]
\ No newline at end of file
